package com.sec.cloudprint.jobmanager;

import com.sec.cloudprint.jobmanager.IJobStatusCallback;
import com.sec.cloudprint.jobmanager.JobData;
import com.sec.cloudprint.jobmanager.DocumentsContentsInfo;
import com.sec.print.mobileprint.pagedata.DocSetInterface;
import com.sec.print.mobileprint.printoptionattribute.PrintOptionAttributeSet; 
import com.sec.print.mobileprint.printerinfo.PrinterInfo;


/**
* Main Interface for calling PrintingService
* 
* <br/>
* <br/>
* Copyright 2010 by Samsung Electronics, Inc.,
*
* This software is the confidential and proprietary information
* of Samsung Electronics, Inc., (Confidential Information).
* You shall not disclose such Confidential Information and 
* shall use it only in accordance with the terms of the license
* agreement you entered into with Samsung.
*/
interface IJobManagerService
{
	/**
	* request Print job to JobManager with specified printing options and selected printer, contents.
	*
	* @param	jobTitle		name of the job. 
	* @param	printOptions	Contains print options like copies, media type media size etc
	* @param	documents		Contains information about the docuent contents.
	* @param	printerInfo		Information of selected printer. (Output stream, PDL type list)
	*/
	void requestPrint( in String jobTitle, in PrintOptionAttributeSet printOptions, in DocSetInterface documents, in com.sec.print.mobileprint.printerinfo.PrinterInfo printerInfo, in DocumentsContentsInfo documentData, in boolean isPrint ,in String statusRequestID);
	
	boolean requestCancelJob(in int jobID);
	
	List<JobData> getAllJobList();
	
	JobData getJobData(in int jobID);
	
	/**
	* change job priority.
	*
	* @param	jobID			id of the job. 
	* @param	numPriority		number of priority, numPriority >= 0
	* @param	documents		Contains information about the docuent contents.
	* @param	printerInfo		Information of selected printer. (Output stream, PDL type list)
	*/
	boolean changePriority(in int jobID, in int numPriority);
	
	/**
	* Add a new callback to the list. This callback will remain in the list until a corresponding call to unregisterStatusCallback.
	* 
	* @param	callbackStatus - callback instance to be added.
	*/
	void registerCallback(in IJobStatusCallback callbackStatus);
	
	/**
	* Remove callback from the list that was previously added with registerCallback
	* 
	* @param	callbackStatus - callback instance to be removed.
	*/
	void unregisterCallback(in IJobStatusCallback callbackStatus);
}
 